/**
  *  \file planetscentral/talk/cmdrender.cc
  *  \brief Talk: RENDER commands
  */

#include "planetscentral/talk/cmdrender.h"
#include "planetscentral/talk/talkconnection.h"
#include "planetscentral/talk/render.h"
#include "planetscentral/dbclient/reconnect.h"
#include "planetscentral/talk/talk.h"
#include "planetscentral/dbclient/dbclient.h"

/** RENDEROPTION command. */
void
doRenderOptions(TalkConnection& conn, IntArgBlock& args)
{
    while (args.getNumArgs() > 0) {
        string_t optUC = strUCase(toStringResult(args.getNext()));
        if (!conn.getRenderState().handleOption(optUC, args)) {
            conn.sendError("400 Invalid option");
            return;
        }
    }
    conn.sendSuccess("OK");
}

/** RENDER command. */
void
doRender(TalkConnection& conn, IntArgBlock& args)
{
    // Get text to render
    args.checkArgumentCountAtLeast(1);
    string_t text = toStringResult(args.getNext());

    // Get options
    RenderState state(conn.getRenderState());
    while (args.getNumArgs() > 0) {
        string_t optUC = strUCase(toStringResult(args.getNext()));
        if (!state.handleOption(optUC, args)) {
            conn.sendError("400 Invalid option");
            return;
        }
    }

    // Do it
    ReconnectingGuard g(database_rc);
    IntStringValue sv(state.render(text, database_connection));
    conn.sendObject(&sv);
}
