/**
  *  \file planetscentral/talk/syntax.cc
  *  \brief Talk: Syntax Highlighter, Base Class
  */

#include "planetscentral/talk/syntax.h"

/** Initialize this highlighter segment.
    \param fmt Format
    \param start Start position
    \param length Length of segment */
void
SyntaxHighlighter::Segment::set(Format fmt, string_t::size_type start, string_t::size_type length)
{
    this->fmt = fmt;
    this->start_pos = start;
    this->length = length;
    this->link.clear();
    this->info.clear();
}

/** Start a segment.
    \param start Start position */
void
SyntaxHighlighter::Segment::start(string_t::size_type start)
{
    set(DefaultFormat, start, 0);
}

/** Finish a segment.
    \param fmt Format
    \param end End position (used to derive length) */
void
SyntaxHighlighter::Segment::finish(Format fmt, string_t::size_type end)
{
    this->fmt    = fmt;
    this->length = end - this->start_pos;
}

/*************************** SyntaxHighlighter ***************************/

SyntaxHighlighter::~SyntaxHighlighter()
{ }

/************************* NullSyntaxHighlighter *************************/

NullSyntaxHighlighter::NullSyntaxHighlighter()
    : pos(0),
      total(0)
{ }

NullSyntaxHighlighter::~NullSyntaxHighlighter()
{ }

void
NullSyntaxHighlighter::init(const string_t& str)
{
    pos = 0;
    total = str.size();
}

bool
NullSyntaxHighlighter::scan(Segment& result)
{
    if (pos < total) {
        result.start(pos);
        pos = total;
        result.finish(DefaultFormat, pos);
        return true;
    } else {
        return false;
    }
}
